@@ -7,7 +7,7 @@ package A1z::HTML5::Template;
 
 sub NAME { my $self = shift; my $NAME; $NAME = "Fast and Easy Web Apps"; return $NAME; }
 
-our $VERSION = '0.14';
+our $VERSION = '0.15';
 
 
 
@@ -213,7 +213,7 @@ sub body_js_css
 		<script src="https://code.jquery.com/ui/1.11.4/jquery-ui.min.js"></script>
 
 		<!-- IE10 viewport hack for Surface/desktop Windows 8 bug -->
-		<script type="text/javascript" src="/jquery/bootstrap/fixed-top/ie10-viewport-bug-workaround.js"></script>
+		<script type="text/javascript" src="https://www.a1z.us/jquery/bootstrap/fixed-top/ie10-viewport-bug-workaround.js"></script>
 
 		<script type="text/javascript">
 		
@@ -878,13 +878,16 @@ sub defaults_end
 my %HTML;
 
 %HTML = (
-	-defaultjquery => qq{
+	-defaultjquery => qq{<!-- -defaultjquery-->\n<!-- jquery-->
 		<script src="https://code.jquery.com/ui/1.11.4/jquery-ui.min.js"></script>
-		<!--bootstrap/jQueryUI-->
+		<!--bootstrap-->
 		<script type="text/javascript" src="https://maxcdn.bootstrapcdn.com/bootstrap/3.3.0/js/bootstrap.min.js"></script>
+		<!--blueimp gallery-->
+		<script src="https://blueimp.github.io/Gallery/js/jquery.blueimp-gallery.min.js"></script>
+		<!-- jquery ui -->
 		<script type="text/javascript" src="https://code.jquery.com/ui/1.11.4/themes/ui-lightness/jquery-ui.css"></script>
 		<!-- IE10 viewport hack for Surface/desktop Windows 8 bug -->
-		<script type="text/javascript" src="/jquery/bootstrap/fixed-top/ie10-viewport-bug-workaround.js"></script>
+		<script type="text/javascript" src="https://www.a1z.us/jquery/bootstrap/fixed-top/ie10-viewport-bug-workaround.js"></script>
 		<script type="text/javascript">
 		
 		// for tabs 
@@ -1026,11 +1029,11 @@ sub html_humanejs_css
       <link rel='stylesheet' href='https://cdnjs.cloudflare.com/ajax/libs/humane-js/3.2.2/themes/boldlight.css'>
       <link rel='stylesheet' href='https://cdnjs.cloudflare.com/ajax/libs/humane-js/3.2.2/themes/jackedup.css'>
       <link rel='stylesheet' href='https://cdnjs.cloudflare.com/ajax/libs/humane-js/3.2.2/themes/libnotify.css'>
-      <link rel='stylesheet' href='/https://cdnjs.cloudflare.com/ajax/libs/humane-js/3.2.2/themes/original.css'>
+      <link rel='stylesheet' href='https://cdnjs.cloudflare.com/ajax/libs/humane-js/3.2.2/themes/original.css'>
 <link rel='stylesheet' href='https://cdnjs.cloudflare.com/ajax/libs/humane-js/3.2.2/themes/flatty.min.css'>
-<link href='http://fonts.googleapis.com/css?family=Ubuntu&v2' rel='stylesheet' type='text/css'>
-<link href='http://fonts.googleapis.com/css?family=Ubuntu+Mono' rel='stylesheet' type='text/css'>
-<link href='http://fonts.googleapis.com/css?family=Cabin+Sketch:700&v2' rel='stylesheet' type='text/css'>
+<link href='https://fonts.googleapis.com/css?family=Ubuntu&v2' rel='stylesheet' type='text/css'>
+<link href='https://fonts.googleapis.com/css?family=Ubuntu+Mono' rel='stylesheet' type='text/css'>
+<link href='https://fonts.googleapis.com/css?family=Cabin+Sketch:700&v2' rel='stylesheet' type='text/css'>
 }; 
 
 }
@@ -1094,7 +1097,7 @@ sub head
 		-htmlshim	=> html_shim_respond, 
 		-humanejs  => html_humanejs_css, 
 		-title 		=> "$ENV{SERVER_NAME}" || "", 
-		-cssLinks => "https://www.a1z.us/A1z/HTML5/Template.css", 
+		-cssLinks => "https://blueimp.github.io/Gallery/css/blueimp-gallery.min.css,https://www.a1z.us/A1z/HTML5/Template.css", 
 		-cssCode => "", 
 		-mobilemeta => qq{<meta name="HandheldFriendly" content="true">
 <meta name="viewport" content="width=device-width, initial-scale=1.0">
@@ -1173,9 +1176,9 @@ sub body
 		-onload => qq{setTitle();},  
 		-nbhead 	=> qq{},
 		-nbpage => qq{}, 
-		-nbmenu => qq{}, 
+		-nbmenu => qq{More}, 
 		-defaultjquery => qq{$HTML{-defaultjquery}}, 
-		-humanejs => qq{<script type="text/javascript" src="https://cdnjs.cloudflare.com/ajax/libs/humane-js/3.2.2/humane.min.js">},
+		-humanejs => qq{<script src="https://cdnjs.cloudflare.com/ajax/libs/humane-js/3.2.2/humane.min.js">},
 		-userjquery => qq{}, 
 		-navbar => html_navbar( $in{-nbmenu}, $in{-nbpage}, " ") , 
 		-content => qq{<div class="content">Content</div>}, 
@@ -1186,18 +1189,22 @@ sub body
 	
 	return qq{<body onload="$in{-onload}">
 <div id="main" class="container">
-		<script type="text/javascript" src="https://www.a1z.us/js/utils/top-nav-bar.js"></script>
-<!--top nav bar begin-->
-<script type="text/javascript">
-//<-- 
-fixed_top_navbar('$in{-nbhead}', '$in{-nbpage}', '$in{-nbmenu}', '', '');
-//-->
-</script>
+	<!--top nav bar begin-->
+	<script type="text/javascript" src="https://www.a1z.us/js/utils/top-nav-bar.js"></script>
+	<script type="text/javascript">
+	//<-- 
+	fixed_top_navbar('$in{-nbhead}', '$in{-nbpage}', '$in{-nbmenu}', '/support-/sales');
+	//-->
+	</script>
 
-$in{-bootstrapbluimp}
+	$in{-bootstrapbluimp}
+
+	$in{-h1}
+
+	$in{-content}
+	
+	$in{-footer}
 
-	<div class="content">$in{-content}</div>
-	<div class="footer">$in{-footer}</div>
 </div>
 
 $in{-defaultjquery}
@@ -1764,15 +1771,17 @@ sub display_gallery_thumbnails
 
 		foreach ( @thumbs ) 
 		{
-			if ( $_ and $_ =~ /(.jpg|.gif|.jpeg)$/ )
+			if ( $_ and $_ =~ /(.jpg|.gif|.jpeg|.png|.tiff)$/ )
 			{
-				$out .= qq{<a href="$in{images_url}/$_" title="$_" data-gallery> <img src="$in{thumbs_url}/$_" alt="Image $_" width="$in{width}" height="$in{height}"> </a> };
+				$out .= qq{\n<a href="$in{images_url}/$_" title="$_" data-gallery> <img src="$in{thumbs_url}/$_" alt="Image $_" width="$in{width}" height="$in{height}"> </a> \n};
 			}
 		}
 	}
 	else
 	{
-		$in{error} .= qq{Image directory does not exist or is inaccessible. Make sure you provided the correct path.};
+		$in{error} .= qq{<p>Image directory does not exist or is inaccessible. Make sure you provided the correct path.</p>};
+
+		$out = $in{error};
 	}
 
 	return $out;
@@ -1801,7 +1810,7 @@ A1z::HTML5::Template - Fast/easy Web Apps in Perl
 
 =head1 VERSION
 
-version 0.14
+version 0.15
 
 =head1 SYNOPSIS
 
@@ -1877,7 +1886,7 @@ version 0.14
 
 =head2 VERSION
 
-	0.14
+	0.15
 
 =head1 Installation
 
